==> festo_edcon-0.8.0-py3-none-any.whl: edcon_tools/position.py <==
"""CLI tool to execute positioning tasks using EDriveMotion."""
import sys
import traceback
from edcon_tools.generic_bus_argparser import GenericBusArgParser
from edrive.edrive_modbus import EDriveModbus
from edrive.edrive_ethernetip import EDriveEthernetip
from edrive.edrive_motion import EDriveMotion


def main():
    """Parses command line arguments and run the example."""
    gparser = GenericBusArgParser('Control EDrive device.')
    gparser.add_argument('-p', '--position', default="10000",
                         help='Target position to be reached')
    gparser.add_argument('-s', '--speed', default="600000",
                         help='Speed used for positioning task')
    gparser.add_argument('-a', '--absolute', action='store_true',
                         help='Use absolute positioning mode')
    gparser.add_argument('-r', '--reference', action='store_true',
                         help='Perform a referencing task before positioning task')

    args = gparser.create()

    # Initialize driver
    if args.com_type == 'modbus':
        edrive = EDriveModbus(
            args.ip_address, flavour=args.flavour)
    elif args.com_type == 'ethernetip':
        edrive = EDriveEthernetip(args.ip_address)

    try:
        with EDriveMotion(edrive) as mot:
            if not mot.acknowledge_faults():
                sys.exit(1)
            if not mot.enable_powerstage():
                sys.exit(1)

            if args.reference:
                if not mot.referencing_task():
                    sys.exit(1)

            mot.position_task(position=int(args.position),
                              velocity=int(args.speed), absolute=args.absolute)
    except ConnectionError:
        print(traceback.format_exc())


if __name__ == "__main__":
    main()

==> festo_edcon-0.9.0-py3-none-any.whl: edcon_tools/position.py <==
"""CLI tool to execute positioning tasks using EDriveMotion."""
import sys
import traceback
from edcon_tools.generic_bus_argparser import GenericBusArgParser
from edrive.edrive_modbus import EDriveModbus
from edrive.edrive_ethernetip import EDriveEthernetip
from edrive.edrive_motion import EDriveMotion


def main():
    """Parses command line arguments and run the example."""
    gparser = GenericBusArgParser('Control EDrive device.')
    gparser.add_argument('-p', '--position', default="10000",
                         help='Target position to be reached')
    gparser.add_argument('-s', '--speed', default="600000",
                         help='Speed used for positioning task')
    gparser.add_argument('-a', '--absolute', action='store_true',
                         help='Use absolute positioning mode')
    gparser.add_argument('-r', '--reference', action='store_true',
                         help='Perform a referencing task before positioning task')

    args = gparser.create()

    # Initialize driver
    if args.com_type == 'modbus':
        edrive = EDriveModbus(args.ip_address)
    elif args.com_type == 'ethernetip':
        edrive = EDriveEthernetip(args.ip_address)

    try:
        with EDriveMotion(edrive) as mot:
            if not mot.acknowledge_faults():
                sys.exit(1)
            if not mot.enable_powerstage():
                sys.exit(1)

            if args.reference:
                if not mot.referencing_task():
                    sys.exit(1)

            mot.position_task(position=int(args.position),
                              velocity=int(args.speed), absolute=args.absolute)
    except ConnectionError:
        print(traceback.format_exc())


if __name__ == "__main__":
    main()
